/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.calendar.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.calendar.ejb.session.CalendarController;
import com.clustercontrol.calendar.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * カレンダ一覧取得クラス
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class GetCalendarList {

    // ----- instance メソッド ----- //

    /**
     * 全てのカレンダ一覧を返します。
     * 
     * @return カレンダ一覧
     */
    public ArrayList getAll() {
		CalendarController calendar = 
			EjbConnectionManager.getConnectionManager().getCalendarController();
		

        ArrayList records = null;
        try {
            records = calendar.getCalendarList();
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (FinderException e) {
        } catch (NamingException e) {
        }
        return records;
    }
    
    /**
     * 全てのカレンダID一覧を返します。
     * 
     * @return カレンダID一覧
     */
    public ArrayList getCalendarIdList() {
		CalendarController calendar = 
			EjbConnectionManager.getConnectionManager().getCalendarController();
		

        ArrayList records = null;
        try {
            records = calendar.getCalendarIdList();
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (FinderException e) {
        } catch (NamingException e) {
        }
        return records;
    }
}