/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.calendar.composite.action;

import java.util.ArrayList;

import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PlatformUI;

import com.clustercontrol.calendar.bean.CalendarListTableDefine;
import com.clustercontrol.calendar.composite.CalendarListComposite;
import com.clustercontrol.calendar.view.AddInfoListView;
import com.clustercontrol.calendar.view.CalendarListView;
import com.clustercontrol.calendar.view.WeekdayInfoListView;

/**
 * カレンダテーブルのSelectionChangedListenerクラス
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class CalendarSelectionChangedListener implements ISelectionChangedListener {
    protected CalendarListComposite m_composite;

    /**
     * コンストラクタ
     * 
     * @param composite
     * @since 1.0.0
     */
    public CalendarSelectionChangedListener(CalendarListComposite composite) {
        m_composite = composite;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.jface.viewers.ISelectionChangedListener#selectionChanged(org.eclipse.jface.viewers.SelectionChangedEvent)
     */
    public void selectionChanged(SelectionChangedEvent event) {
        String calenadarId = null;
        boolean calendarSelectFlg = false;
        
        StructuredSelection selection = (StructuredSelection) event.getSelection();
        
        //カレンダIDを取得
        if ( selection.getFirstElement() != null) {
            ArrayList info = (ArrayList) selection.getFirstElement();
            calenadarId = (String) info.get(CalendarListTableDefine.CALENDAR_ID);
            //カレンダIDを設定
            m_composite.setCalendarId(calenadarId);
            
            //カレンダーが選択フラグを立てる
            calendarSelectFlg = true;
        }

        //アクティブページを手に入れる
        IWorkbenchPage page = PlatformUI.getWorkbench()
                .getActiveWorkbenchWindow().getActivePage();
        
        //カレンダ[一覧]ビューのボタン（アクション）の使用可/不可を設定する
        IViewPart viewPart = page.findView(CalendarListView.ID);
        if (selection != null && viewPart != null) {
        	CalendarListView view = (CalendarListView) viewPart
        			.getAdapter(CalendarListView.class);
        	
        	//ボタン（アクション）の使用可/不可を設定する
        	view.setEnabledAction(selection.size(), selection);
        }
        
        //ビューを更新する
        viewPart = page.findView(WeekdayInfoListView.ID);
        if (viewPart != null) {
        	WeekdayInfoListView view = (WeekdayInfoListView) viewPart
                    .getAdapter(WeekdayInfoListView.class);
            view.update(calenadarId);
            
            //ボタン（アクション）の使用可/不可を設定する
            view.setEnabledAction(0, selection, calendarSelectFlg);
        }
        
        //ビューを更新する
        viewPart = page.findView(AddInfoListView.ID);
        if (viewPart != null) {
        	AddInfoListView view = (AddInfoListView) viewPart
                    .getAdapter(AddInfoListView.class);
            view.update(calenadarId);
            
            //ボタン（アクション）の使用可/不可を設定する
            view.setEnabledAction(0, selection, calendarSelectFlg);
        }
    }
}

