/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.calendar.view;

import org.eclipse.jface.action.ActionContributionItem;
import org.eclipse.jface.action.IMenuListener;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Menu;

import com.clustercontrol.calendar.composite.WeekdayInfoListComposite;
import com.clustercontrol.calendar.composite.action.WeekdayInfoListSelectionChangedListener;
import com.clustercontrol.calendar.view.action.WeekdayInfoAddAction;
import com.clustercontrol.calendar.view.action.WeekdayInfoDeleteAction;
import com.clustercontrol.calendar.view.action.WeekdayInfoModifyAction;
import com.clustercontrol.view.CommonViewPart;

/**
 * カレンダ曜日別情報一覧ビュークラス
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class WeekdayInfoListView extends CommonViewPart {
	public static final String ID = "com.clustercontrol.calendar.view.WeekdayInfoListView";
	
	private WeekdayInfoListComposite m_weekdayList = null;
	
	/**
	 * コンストラクタ
	 */
	public WeekdayInfoListView() {
		super();
	}
	
	/**
	 * ViewPartへのコントロール作成処理
	 * 
	 * @see org.eclipse.ui.IWorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
	 */
	public void createPartControl(Composite parent) {
		GridLayout layout = new GridLayout(1, true);
		parent.setLayout(layout);
		layout.marginHeight = 0;
		layout.marginWidth = 0;
		
		m_weekdayList = new WeekdayInfoListComposite(parent, SWT.NONE);
		GridData gridData = new GridData();
		gridData.horizontalAlignment = GridData.FILL;
		gridData.verticalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		gridData.grabExcessVerticalSpace = true;
		m_weekdayList.setLayoutData(gridData);
		
		//ポップアップメニュー作成
		createContextMenu();
		
		// ボタン（アクション）を制御するリスナーを登録        
		this.m_weekdayList.getTableViewer().addSelectionChangedListener(
				new WeekdayInfoListSelectionChangedListener());
		
		//ビューを更新
		this.update(null);
	}
	
	/**
	 * ポップアップメニュー作成
	 * 
	 *  
	 */
	protected void createContextMenu() {
		MenuManager menuManager = new MenuManager();
		menuManager.setRemoveAllWhenShown(true);
		menuManager.addMenuListener(new IMenuListener() {
			/*
			 * (non-Javadoc)
			 * 
			 * @see org.eclipse.jface.action.IMenuListener#menuAboutToShow(org.eclipse.jface.action.IMenuManager)
			 */
			public void menuAboutToShow(IMenuManager manager) {
				//メニュー項目設定
				fillContextMenu(manager);
			}
		});
		
		Menu menu = menuManager.createContextMenu(m_weekdayList.getTable());
		m_weekdayList.getTable().setMenu(menu);
	}
	
	/**
	 * メニュー項目追加
	 * 
	 * @param manager
	 */
	protected void fillContextMenu(IMenuManager manager) {
		//ビューのアクションのインスタンスを取得
		IToolBarManager toolbar = this.getViewSite().getActionBars()
		.getToolBarManager();
		ActionContributionItem add = 
			(ActionContributionItem) toolbar.find(WeekdayInfoAddAction.ID);
		ActionContributionItem modify = 
			(ActionContributionItem) toolbar.find(WeekdayInfoModifyAction.ID);
		ActionContributionItem delete = 
			(ActionContributionItem) toolbar.find(WeekdayInfoDeleteAction.ID);
		
		//ポップアップメニューにアクションを追加
		manager.add(add.getAction());
		manager.add(modify.getAction());
		manager.add(delete.getAction());
	}
	
	/**
	 * カレンダ曜日別一覧ビュー更新
	 */
	public void update(String calendarId) {
		m_weekdayList.update(calendarId);
	}
	
	/**
	 * コンポジット取得処理
	 * 
	 * @return
	 */
	public WeekdayInfoListComposite getComposite() {
		return m_weekdayList;
	}
	
	/**
	 * ビューのアクションの有効/無効を設定します。
	 * 
	 * @param num 選択イベント数
	 * @param selection ボタン（アクション）を有効にするための情報
	 * @param flg WeekdayInfoAddActionボタンの有効/無効の選定
	 */
	public void setEnabledAction(int num, ISelection selection, boolean flg) {
		//ビューアクションの使用可/不可を設定
		super.setEnabledAction(WeekdayInfoAddAction.ID, selection);
		super.setEnabledAction(WeekdayInfoModifyAction.ID, selection);
		super.setEnabledAction(WeekdayInfoDeleteAction.ID, selection);
		
		//デフォルト設定
		super.setEnabledAction(WeekdayInfoAddAction.ID, false);
		super.setEnabledAction(WeekdayInfoModifyAction.ID, false);
		super.setEnabledAction(WeekdayInfoDeleteAction.ID, false);
		
		//WeekdayInfoAddActionボタンの設定
		if (flg) {
			super.setEnabledAction(WeekdayInfoAddAction.ID, true);
		}
		
		if (num > 0){
			super.setEnabledAction(WeekdayInfoModifyAction.ID, true);
			super.setEnabledAction(WeekdayInfoDeleteAction.ID, true);
		} else {
			super.setEnabledAction(WeekdayInfoModifyAction.ID, false);
			super.setEnabledAction(WeekdayInfoDeleteAction.ID, false);
		}
	}
}