/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.monitor.run.composite;

import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import com.clustercontrol.bean.MonitorBlockConstant;
import com.clustercontrol.dialog.ValidateResult;
import com.clustercontrol.monitor.run.bean.MonitorInfo;
import com.clustercontrol.util.Messages;

/**
 * 監視単位コンポジットクラスです。
 * <p>
 * <dl>
 *  <dt>コンポジット</dt>
 *  <dd>「監視単位」 ラジオボタン</dd>
 * </dl>
 * 
 * @version 2.1.0
 * @since 2.0.0
 */
public class MonitorBlockComposite extends Composite {
	
	/** ノード ボタン。 */
	private Button m_radioNode = null;
	
	/** スコープ ボタン。 */
	private Button m_radioScope = null;
	
//	/** スコープとノード ボタン。 */
//	private Button m_radioScopeNode = null;
	
	/**
	 * インスタンスを返します。
	 * <p>
	 * 初期処理を呼び出し、コンポジットを配置します。
	 * 
	 * @param parent 親のコンポジット
	 * @param style スタイル
	 * 
	 * @see org.eclipse.swt.SWT
	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
	 * @see #initialize()
	 */
	public MonitorBlockComposite(Composite parent, int style) {
		super(parent, style);
		
		this.initialize();
	}
	
	/**
	 * コンポジットを配置します。
	 */
	private void initialize() {
		
		// 変数として利用されるグリッドデータ
		GridData gridData = null;
		
		GridLayout layout = new GridLayout(1, true);
		layout.marginHeight = 0;
		layout.marginWidth = 0;
		layout.numColumns = 5;	
		this.setLayout(layout);
		
		/*
		 * 監視単位
		 */
		// ノード
		this.m_radioNode = new Button(this, SWT.RADIO);
		gridData = new GridData();
		gridData.horizontalSpan = 1;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		this.m_radioNode.setLayoutData(gridData);
		this.m_radioNode.setText(Messages.getString("node"));
		
		// スコープ
		this.m_radioScope = new Button(this, SWT.RADIO);
		gridData = new GridData();
		gridData.horizontalSpan = 1;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		this.m_radioScope.setLayoutData(gridData);
		this.m_radioScope.setText(Messages.getString("scope"));
		
		// スコープとノード
//		this.m_radioScopeNode = new Button(this, SWT.RADIO);
//		gridData = new GridData();
//		gridData.horizontalSpan = 1;
//		gridData.horizontalAlignment = GridData.FILL;
//		gridData.grabExcessHorizontalSpace = true;
//		this.m_radioScopeNode.setLayoutData(gridData);
//		this.m_radioScopeNode.setText(Messages.getString("scope.node"));
		
		// 空白
		Label label = new Label(this, SWT.NONE);
		gridData = new GridData();
		gridData.horizontalSpan = 3;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);
	}
	
	/**
	 * 引数で指定された監視情報の値を、各項目に設定します。
	 * 
	 * @param info 設定値として用いる監視情報
	 */
	public void setInputData(MonitorInfo info) {
		
		if(info != null){
//			if(info.getMonitorBlock() == MonitorBlockConstant.TYPE_ALL) {
//			this.m_radioScopeNode.setSelection(true);
			if(info.getMonitorBlock() == MonitorBlockConstant.TYPE_SCOPE) {
				this.m_radioScope.setSelection(true);
			}
			else{
				this.m_radioNode.setSelection(true);
			}
		}
	}
	
	/**
	 * 引数で指定された監視情報に、入力値を設定します。
	 * <p>
	 * 入力値チェックを行い、不正な場合は認証結果を返します。
	 * 不正ではない場合は、<code>null</code>を返します。
	 * 
	 * @param info 入力値を設定する監視情報
	 * @return 検証結果
	 */
	public ValidateResult createInputData(MonitorInfo info) {
		
		if(info != null){
//			if (this.m_radioScopeNode.getSelection()) {
//			info.setMonitorBlock(MonitorBlockConstant.TYPE_ALL);
			if (this.m_radioScope.getSelection()) {
				info.setMonitorBlock(MonitorBlockConstant.TYPE_SCOPE);
			}else {
				info.setMonitorBlock(MonitorBlockConstant.TYPE_NODE);
			}
		}
		return null;
	}
	
	/* (非 Javadoc)
	 * @see org.eclipse.swt.widgets.Control#setEnabled(boolean)
	 */
	@Override
	public void setEnabled(boolean enabled) {
		this.m_radioNode.setEnabled(enabled);
		this.m_radioScope.setEnabled(enabled);
//		this.m_radioScopeNode.setEnabled(enabled);
	}
}