/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;

import javax.naming.NamingException;

import org.eclipse.jface.dialogs.MessageDialog;
import org.quartz.SchedulerException;

import com.clustercontrol.jobmanagement.ejb.session.JobController;
import com.clustercontrol.jobmanagement.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * ジョブ[実行予定]ビューの左側の実行予定一覧情報を取得するクラスです。
 * 
 * マネージャにSessionBean経由でアクセスし、実行予定一覧情報を取得する
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class GetRunScheduleList {
	
	/**
	 * マネージャにSessionBean経由でアクセスし、<BR>
	 * 実行予定一覧情報を取得する
	 * 
	 * @return 実行予定一覧情報（Objectの2次元配列）
	 * 
	 * @see com.clustercontrol.jobmanagement.ejb.session.JobController
	 * @see com.clustercontrol.jobmanagement.util.EjbConnectionManager
	 * @see com.clustercontrol.jobmanagement.ejb.session.JobControllerBean#getRunScheduleList()
	 */
	public ArrayList get() {
		JobController job = 
			EjbConnectionManager.getConnectionManager().getJobController();
		
		ArrayList list = null;
		try {
			list = job.getRunScheduleList();
		} catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
				MessageDialog.openInformation(null, Messages.getString("message"),
						Messages.getString("message.accesscontrol.16"));
			}
		} catch (NamingException e) {
		} catch (SchedulerException e) {
		}
		return list;
	}
}
