/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.view.action;

import java.util.ArrayList;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;

import com.clustercontrol.jobmanagement.action.DeleteSchedule;
import com.clustercontrol.jobmanagement.bean.ScheduleTableDefine;
import com.clustercontrol.jobmanagement.composite.ScheduleListComposite;
import com.clustercontrol.jobmanagement.view.ScheduleListView;
import com.clustercontrol.util.Messages;

/**
 * ジョブ[スケジュール]ビューの「削除」のアクションクラスです。
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class DeleteScheduleAction implements IViewActionDelegate {
	/** アクションID */
    public static final String ID = "com.clustercontrol.jobmanagement.view.action.DeleteScheduleAction";
    /** ビュー */
    protected IViewPart m_view;

    /**
     * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
     * 
     * @param view ビューのインスタンス
     * 
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart view) {
        m_view = view;
    }

    /**
     * ジョブ[スケジュール]ビューの「削除」が押された場合に、スケジュールを削除します。
     * <p>
	 * <ol>
	 * <li>ジョブ[スケジュール]ビューから選択されたスケジュールを取得します。</li>
	 * <li>削除の確認ダイアログを表示します。</li>
	 * <li>スケジュールを削除します。</li>
	 * <li>ジョブ[スケジュール]ビューを更新します。</li>
	 * </ol>
     * 
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
     * @see com.clustercontrol.jobmanagement.view.ScheduleListView
     * @see com.clustercontrol.jobmanagement.composite.ScheduleListComposite
     * @see com.clustercontrol.jobmanagement.action.DeleteSchedule#deleteSchedule(String)
     */
    public void run(IAction action) {
        if (m_view instanceof ScheduleListView) {
            ScheduleListView view = (ScheduleListView) m_view
                    .getAdapter(ScheduleListView.class);
            ScheduleListComposite composite = view.getComposite();

            ArrayList item = composite.getSelectItem();
            if (item instanceof ArrayList) {
                String message = Messages.getString("schedule") + "[" 
                		+ (String) item.get(ScheduleTableDefine.SCHE_ID) + "]"
                		+ Messages.getString("message.job.2");
                if (MessageDialog.openQuestion(
            			null, 
            			Messages.getString("confirmed"), 
            			message)) {
                    DeleteSchedule delete = new DeleteSchedule();
                    delete.deleteSchedule((String) item
                            .get(ScheduleTableDefine.SCHE_ID));
                }
            }

            view.update();
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
     *      org.eclipse.jface.viewers.ISelection)
     */
    public void selectionChanged(IAction action, ISelection selection) {

    }
}