/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.jobmanagement.dao;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;

import javax.ejb.CreateException;
import javax.ejb.DuplicateKeyException;
import javax.ejb.EJBException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.bean.JobConstant;
import com.clustercontrol.commons.util.ConnectionManager;
import com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoBean;
import com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoPK;

/**
 * ジョブファイル転送情報のDAOインターフェースを実装するクラスです。
 * 
 * @version 2.1.0
 * @since 2.1.0
 * 
 * @see com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoBean
 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAO
 */
public class JobFileInfoDAOImpl implements JobFileInfoDAO {
	
	/** ログ出力のインスタンス。 */
	protected static Log m_log = LogFactory.getLog(JobFileInfoDAOImpl.class);
	
	public void init() {
	}
	
	/** 
	 * SELECT文を発行します。
	 * 引数で指定されたプライマリキーで検索し、取得したデータベースの内容をEntity Beanに反映します。
	 * 
	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoPK, com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoBean)
	 */
	public void load(JobFileInfoPK pk, JobFileInfoBean ejb) throws EJBException {
		m_log.debug("load() start : " + pk.toString());
		
		Connection conn = null;
		PreparedStatement stmt = null;
		ResultSet res = null;
		
		try {
			conn = ConnectionManager.getConnectionManager().getConnection();
			
			//SQL文の定義
			String sql = "SELECT * FROM cc_job_file_info WHERE session_id = ? AND job_id = ?";
			//SQL文のセット
			stmt = conn.prepareStatement(sql);
			
			stmt.setString(1, pk.getSession_id());
			stmt.setString(2, pk.getJob_id());
			
			res = stmt.executeQuery();
			
			if (res.next()) {
				//取得した値をBeanにセット
				ejb.setCheck_flg(res.getInt("check_flg"));
				ejb.setCompression_flg(res.getInt("compression_flg"));
				ejb.setDest_directory(res.getString("dest_directory"));
				ejb.setDest_facility_id(res.getString("dest_facility_id"));
				ejb.setDest_work_dir(res.getString("dest_work_dir"));
				ejb.setEffective_user(res.getString("effective_user"));
				ejb.setJob_id(res.getString("job_id"));
				ejb.setProcess_mode(res.getInt("process_mode"));
				ejb.setSession_id(res.getString("session_id"));
				ejb.setSrc_facility_id(res.getString("src_facility_id"));
				ejb.setSrc_file(res.getString("src_file"));
				ejb.setSrc_work_dir(res.getString("src_work_dir"));
			} else {
				String msg = "JobFileInfo data is not found.";
				m_log.error("load() error : " + pk.toString() + " SQLException " + msg);
				throw new EJBException(msg);
			}
		} catch (SQLException e) {
			m_log.error("load() error : " + pk.toString() + " SQLException");
			throw new EJBException(e.getMessage());
		} finally {
			//コネクション、結果セット、プリペアドステートメントのクローズ
			try {
				if (stmt != null) {
					stmt.close();
				}
				if (res != null) {
					res.close();
				}
				if (conn != null) {
					conn.close();
				}
			} catch (SQLException e1) {
				m_log.error("load() error : " + pk.toString() + " SQLException " + e1.getMessage());
				throw new EJBException(e1.getMessage());
			}
		}
		m_log.debug("load() end : " + pk.toString());
	}
	
	/**
	 * UPDATE文を発行します。
	 * 引数で指定されたEntity Beanの内容でデータベースを更新します。
	 * 
	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAO#store(com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoBean)
	 */
	public void store(JobFileInfoBean ejb) throws EJBException {
		m_log.debug("store() start : " + ejb.getSession_id() + ", " + ejb.getJob_id());
		
		Connection conn = null;
		PreparedStatement stmt = null;
		
		try {
			conn = ConnectionManager.getConnectionManager().getConnection();
			//SQL文の定義
			StringBuilder sql = new StringBuilder();
			sql.append("UPDATE cc_job_file_info SET ");
			sql.append("process_mode = ?, ");
			sql.append("src_facility_id = ?, ");
			sql.append("dest_facility_id = ?, ");
			sql.append("src_file = ?, ");
			sql.append("src_work_dir = ?, ");
			sql.append("dest_directory = ?, ");
			sql.append("dest_work_dir = ?, ");
			sql.append("compression_flg = ?, ");
			sql.append("check_flg = ?, ");
			sql.append("effective_user = ? ");
			sql.append("WHERE session_id = ? AND ");
			sql.append("job_id = ?");
			
			//SQL文のセット
			stmt = conn.prepareStatement(sql.toString());
			
			stmt.setInt(1, ejb.getProcess_mode());
			stmt.setString(2, ejb.getSrc_facility_id());
			stmt.setString(3, ejb.getDest_facility_id());
			stmt.setString(4, ejb.getSrc_file());
			stmt.setString(5, ejb.getSrc_work_dir());
			stmt.setString(6, ejb.getDest_directory());
			stmt.setString(7, ejb.getDest_work_dir());
			stmt.setInt(8, ejb.getCompression_flg());
			stmt.setInt(9, ejb.getCheck_flg());
			stmt.setString(10, ejb.getEffective_user());
			stmt.setString(11, ejb.getSession_id());
			stmt.setString(12, ejb.getJob_id());
			
			int row = stmt.executeUpdate();
			
			if (row != 1) {
				String msg = "result row is not 1";
				m_log.error("store() error : " + ejb.getSession_id() + ", "
						+ ejb.getJob_id() + " SQLException" + msg);
				throw new EJBException(msg);
			}
		} catch (SQLException e) {
			m_log.error("store() error : " + ejb.getSession_id() + ", "
					+ ejb.getJob_id() + " SQLException");
			throw new EJBException(e.getMessage());
		} finally {
			// コネクション、結果セット、プリペアドステートメントのクローズ
			try {
				if (stmt != null) {
					stmt.close();
				}
				if (conn != null) {
					conn.close();
				}
			} catch (SQLException e1) {
				m_log.error("store() error : " + ejb.getSession_id() + ", "
						+ ejb.getJob_id() + " SQLException");
				throw new EJBException(e1.getMessage());
			}
		}
		m_log.debug("store() end : " + ejb.getSession_id() + ", " + ejb.getJob_id());
	}
	
	/**
	 * DELETE文を発行します。
	 * 引数で指定されたプライマリキーでデータベースから削除します。
	 * 
	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAO#remove(com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoPK)
	 */
	public void remove(JobFileInfoPK pk) throws RemoveException, EJBException {
		m_log.debug("remove() start : " + pk.toString());
		
		Connection conn = null;
		PreparedStatement stmt = null;
		try {
			conn = ConnectionManager.getConnectionManager().getConnection();
			
			//SQL文の定義
			String sql = "DELETE FROM cc_job_file_info WHERE session_id = ? AND job_id = ?";
			//SQL文のセット
			stmt = conn.prepareStatement(sql);
			
			stmt.setString(1, pk.getSession_id());
			stmt.setString(2, pk.getJob_id());
			
			int row = stmt.executeUpdate();
			
			if (row != 1 ) {
				String msg = "result row is not 1";
				m_log.error("remove() error : " + pk.toString() + " SQLException" + msg);
				throw new EJBException(msg);	
			}
		} catch (SQLException e) {
			m_log.error("remove() error : " + pk.toString() + " SQLException");
			throw new EJBException(e.getMessage());
			
		} finally {
			try {
				if(stmt != null){
					stmt.close();
				}
				if(conn != null){
					conn.close();
				}
			} catch (SQLException e1) {
				m_log.error("remove() error : " + pk.toString() + " SQLException");
				throw new EJBException(e1.getMessage());
			}
		}
		m_log.debug("remove() end : " + pk.toString());
	}
	
	/**
	 * INSERT文を発行します。
	 * 引数で指定されたEntity Beanの内容をデータベースに挿入し、プライマリキーを返します。
	 * 
	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAO#create(com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoBean)
	 */
	public JobFileInfoPK create(JobFileInfoBean ejb) throws CreateException, EJBException {
		m_log.debug("create() start : " + ejb.getSession_id() + ", " + ejb.getJob_id());
		
		Connection conn = null;
		PreparedStatement stmt = null;
		JobFileInfoPK pk;
		try {
			conn = ConnectionManager.getConnectionManager().getConnection();
			//SQL文の定義
			StringBuilder sql = new StringBuilder();
			sql.append("INSERT INTO cc_job_file_info (");
			sql.append("session_id, ");
			sql.append("job_id, ");
			sql.append("process_mode, ");
			sql.append("src_facility_id, ");
			sql.append("dest_facility_id, ");
			sql.append("src_file, ");
			sql.append("src_work_dir, ");
			sql.append("dest_directory, ");
			sql.append("dest_work_dir, ");
			sql.append("compression_flg, ");
			sql.append("check_flg, ");
			sql.append("effective_user) ");
			sql.append("VALUES (?,?,?,?,?,?,?,?,?,?,?,?)");
			
			//SQL文のセット
			stmt = conn.prepareStatement(sql.toString());
			
			stmt.setString(1, ejb.getSession_id());
			stmt.setString(2, ejb.getJob_id());
			stmt.setInt(3, ejb.getProcess_mode());
			stmt.setString(4, ejb.getSrc_facility_id());
			stmt.setString(5, ejb.getDest_facility_id());
			stmt.setString(6, ejb.getSrc_file());
			stmt.setString(7, ejb.getSrc_work_dir());
			stmt.setString(8, ejb.getDest_directory());
			stmt.setString(9, ejb.getDest_work_dir());
			stmt.setInt(10, ejb.getCompression_flg());
			stmt.setInt(11, ejb.getCheck_flg());
			stmt.setString(12, ejb.getEffective_user());
			
			int row =	stmt.executeUpdate();
			pk = new JobFileInfoPK(
					ejb.getSession_id(),
					ejb.getJob_id());
			
			if (row != 1) {
				String msg = "result row is not 1";
				m_log.error("create() error : " + ejb.getSession_id() + ", " + ejb.getJob_id() + " SQLException");
				throw new EJBException(msg);
			}
		} catch (SQLException e) {
			if(e.getSQLState().equals("23505")){
				m_log.error("create() error : " + ejb.getSession_id() + ", " + ejb.getJob_id() + " SQLException" + "DuplicateKeyException ");
				throw new DuplicateKeyException(e.getMessage());
			}
			throw new CreateException(e.getMessage());
		}finally{
			try {
				if(stmt != null){
					stmt.close();
				}
				if(conn != null){
					conn.close();
				}
			} catch (SQLException e1) {
				m_log.error("create() error : " + ejb.getSession_id() + ", " + ejb.getJob_id() + " SQLException");
				throw new EJBException(e1.getMessage());
			}
		}
		m_log.debug("create() end : " + ejb.getSession_id() + ", " + ejb.getJob_id());
		return pk;
	}
	
	/**
	 * 全件取得するSELECT文を発行します。
	 * 取得したデータのプライマリキーをコレクションに格納し返します。
	 * 
	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoBean#ejbFindAll()
	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAO#findAll()
	 */
	public Collection findAll() throws FinderException {
		m_log.debug("findAll() start : ");
		
		ArrayList<JobFileInfoPK> ret = new ArrayList<JobFileInfoPK>();
		
		Connection conn = null;
		PreparedStatement stmt = null;
		ResultSet res = null;
		try {
			conn = ConnectionManager.getConnectionManager().getConnection();	
			//SQL文の定義
			String sql = "SELECT * FROM cc_job_file_info";
			//SQL文のセット
			stmt = conn.prepareStatement(sql);
			res = stmt.executeQuery();
			
			while(res.next()) {
				JobFileInfoPK pk= new JobFileInfoPK(
						res.getString("session_id"),
						res.getString("job_id")
				);
				ret.add(pk);
			}
			
		} catch (SQLException e) {
			m_log.error("findAll() error :  SQLException");
			throw new EJBException(e.getMessage());
		}  finally{
			try {
				if(stmt != null){
					stmt.close();}
				if(res != null){
					res.close();}
				if(conn != null){
					conn.close();
				}
			} catch (SQLException e1) {
				m_log.error("findAll() error :  SQLException");
				throw new EJBException(e1.getMessage());
			}
		}
		m_log.debug("findAll() end : ");
		return ret;
	}
	
	/**
	 * 1件取得するSELECT文を発行します。
	 * 引数で指定されたプライマリキーで、データベースを検索します。
	 * 
	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoBean#ejbFindByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoPK)
	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAO#findByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoPK)
	 */
	public JobFileInfoPK findByPrimaryKey(JobFileInfoPK pk) throws FinderException {
		m_log.debug("findByPrimaryKey() start : " + pk.toString());
		
		Connection conn = null;
		PreparedStatement stmt = null;
		ResultSet res = null;
		try {
			conn = ConnectionManager.getConnectionManager().getConnection();
			
			//SQL文の定義
			String sql = "SELECT * FROM cc_job_file_info WHERE session_id = ? AND job_id = ?";
			//SQL文のセット
			stmt = conn.prepareStatement(sql);
			
			stmt.setString(1, pk.getSession_id());
			stmt.setString(2, pk.getJob_id());
			
			res = stmt.executeQuery();
			
			if (res.next()) {
				return pk;
			} else {
				String msg = "id " + pk.toString() + " not found.";
				throw new FinderException(msg);
			}
		} catch (SQLException e) {
			m_log.error("find() error : " + pk.toString() + " SQLException");
			throw new EJBException(e.getMessage());
		}  finally{
			try {
				if(stmt != null){
					stmt.close();}
				if(res != null){
					res.close();}
				if(conn != null){
					conn.close();
				}
			} catch (SQLException e1) {
				m_log.error("find() error : " + pk.toString() + " SQLException");
				throw new EJBException(e1.getMessage());
			}
			m_log.debug("findByPrimaryKey() end : " + pk.toString());
		}
	}
	
	/**
	 * ジョブファイル転送情報をジョブファイル転送マスタから作成します。
	 * 
	 * @param sessionId セッションID
	 * @param jobs ジョブIDのコレクション
	 * @throws CreateException
	 * 
	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoBean#ejbHomeMakeSession(String, Collection)
	 */
	public Collection makeSession(String sessionId, Collection jobs) throws CreateException{
		m_log.debug("makeSession() start : " + sessionId );
		
		ArrayList<Hashtable> fileJobs = new ArrayList<Hashtable>();
		
		Connection conn=null; 
		Connection connMaster = null;
		PreparedStatement stmt=null;
		PreparedStatement stmtMaster= null;
		String jobId = null;
		
		try {
			conn = ConnectionManager.getConnectionManager().getConnection();
			connMaster = ConnectionManager.getConnectionManager().getConnection();
			
			//SQL文の定義(INSERT)
			StringBuilder sql = new StringBuilder();
			sql.append("INSERT INTO cc_job_file_info (");
			sql.append("session_id, ");
			sql.append("job_id, ");
			sql.append("process_mode, ");
			sql.append("src_facility_id, ");
			sql.append("dest_facility_id, ");
			sql.append("src_file, ");
			sql.append("src_work_dir, ");
			sql.append("dest_directory, ");
			sql.append("dest_work_dir, ");
			sql.append("compression_flg, ");
			sql.append("check_flg, ");
			sql.append("effective_user) ");
			sql.append("VALUES (?,?,?,?,?,?,?,?,?,?,?,?)");
			
			//SQLのセット(INSERT)
			stmt = conn.prepareStatement(sql.toString());		
			stmt.setString(1,sessionId);
			
			//SQL文の定義(マスタ検索)
			StringBuilder sqlMaster = new StringBuilder();
			sqlMaster.append("SELECT ");
			sqlMaster.append("cc_job_mst.job_type, ");
			sqlMaster.append("cc_job_file_mst.job_id, ");
			sqlMaster.append("cc_job_file_mst.process_mode, ");
			sqlMaster.append("cc_job_file_mst.src_facility_id, ");
			sqlMaster.append("cc_job_file_mst.dest_facility_id, ");
			sqlMaster.append("cc_job_file_mst.src_file, ");
			sqlMaster.append("cc_job_file_mst.src_work_dir, ");
			sqlMaster.append("cc_job_file_mst.dest_directory, ");
			sqlMaster.append("cc_job_file_mst.dest_work_dir, ");
			sqlMaster.append("cc_job_file_mst.compression_flg, ");
			sqlMaster.append("cc_job_file_mst.check_flg, ");
			sqlMaster.append("cc_job_file_mst.effective_user ");
			sqlMaster.append("FROM cc_job_mst, cc_job_file_mst ");
			sqlMaster.append("WHERE ");
			sqlMaster.append("(cc_job_mst.job_id=cc_job_file_mst.job_id ");
			sqlMaster.append("AND cc_job_mst.job_id=");
			sqlMaster.append(" ? )");
			
			//SQLのセット(マスタ検索)
			stmtMaster = connMaster.prepareStatement(sqlMaster.toString());
			
			Iterator it = jobs.iterator();
			while(it.hasNext()){
				//ジョブID取得
				Hashtable ht = (Hashtable)it.next();
				jobId = (String)ht.get("jobId");
				
				//SQL実行(マスタ検索)
				stmtMaster.setString(1, jobId);
				ResultSet resMaster = stmtMaster.executeQuery();
				
				if (resMaster.next()) {
					if(resMaster.getInt("job_type") == JobConstant.TYPE_FILEJOB){
						//ファイル転送ジョブの場合、INSERTを実行
						stmt.setString(2, resMaster.getString("job_id"));
						stmt.setInt(3, resMaster.getInt("process_mode"));
						stmt.setString(4, resMaster.getString("src_facility_id"));
						stmt.setString(5, resMaster.getString("dest_facility_id"));
						stmt.setString(6, resMaster.getString("src_file"));
						stmt.setString(7, resMaster.getString("src_work_dir"));
						stmt.setString(8, resMaster.getString("dest_directory"));
						stmt.setString(9, resMaster.getString("dest_work_dir"));
						stmt.setInt(10, resMaster.getInt("compression_flg"));
						stmt.setInt(11, resMaster.getInt("check_flg"));
						stmt.setString(12, resMaster.getString("effective_user"));
						
						int row =	stmt.executeUpdate();
						if (row != 1) {
							String msg = "result row is not 1";
							m_log.error("makeSession() error : " + sessionId + ", " + resMaster.getString("job_id") + " SQLException");
							throw new EJBException(msg);
						}
						fileJobs.add(ht);
					}
				}
				resMaster.close();
			}
		} catch (SQLException e) {
			if(e.getSQLState().equals("23505")){
				m_log.error("makeSession() error : " + sessionId + ", " + jobId+ " SQLException" + "DuplicateKeyException ");
				throw new DuplicateKeyException(e.getMessage());
			}
			throw new CreateException(e.getMessage());
		} finally {
			try {
				if(stmt != null){
					stmt.close();
				}
				if(stmtMaster != null){
					stmtMaster.close();
				}
				if(conn != null){
					conn.close();
				}
				if(connMaster != null){
					connMaster.close();
				}
			} catch (SQLException e1) {
				m_log.error("makeSession() error : " + sessionId + ", " + jobId + " SQLException");
				throw new EJBException(e1.getMessage());
			}
		}
		m_log.debug("makeSession() end : " + sessionId);
		
		return fileJobs;
	}
}
