/*
 
Copyright (C) 2007 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.maintenance.action;

import java.rmi.RemoteException;
import java.util.ArrayList;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.maintenance.ejb.entity.MaintenanceInfoData;
import com.clustercontrol.maintenance.ejb.session.MaintenanceController;
import com.clustercontrol.maintenance.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * メンテナンス情報を取得するクラスです。
 * 
 * @version 2.2.0
 * @since 2.2.0
 */
public class GetMaintenance {

	
	/**
	 * メンテナンス情報を返します。
	 * 
	 * @param maintenanceId
	 * @return
	 */
	public MaintenanceInfoData getMaintenanceInfo(String maintenanceId) {
		
    	MaintenanceController maintenance = EjbConnectionManager.getConnectionManager().getMaintenanceController();
    	MaintenanceInfoData info = null;
    	
		try {
			info = maintenance.getMaintenanceInfo(maintenanceId);
		} catch (RemoteException e) {
			// アクセス権なしの場合、エラーダイアログを表示する
			MessageDialog.openInformation(null, Messages.getString("message"),
					Messages.getString("message.accesscontrol.16"));
		} catch (FinderException e) {
		} catch (NamingException e) {
		} catch (CreateException e) {
		}
    	return info;
	}
    
    /**
     * メンテナンス一覧を返します。
     * 
     * @return メンテナンス一覧
     */
    public ArrayList getMaintenanceList() {

    	MaintenanceController maintenance = EjbConnectionManager.getConnectionManager().getMaintenanceController();
    	ArrayList records = null;
    	try {
			records = maintenance.getMaintenanceList();
		} catch (RemoteException e) {
			// アクセス権なしの場合、エラーダイアログを表示する
			MessageDialog.openInformation(null, Messages.getString("message"),
					Messages.getString("message.accesscontrol.16"));
		} catch (FinderException e) {
		} catch (NamingException e) {
		} catch (CreateException e) {
		}
    	return records;
    }
    
    public ArrayList getMaintenanceTypeList() {
    	
    	MaintenanceController maintenance = EjbConnectionManager.getConnectionManager().getMaintenanceController();
    	ArrayList records = null;
    	
		try {
			records = maintenance.getMaintenanceTypeList();
		} catch (RemoteException e) {
			// アクセス権なしの場合、エラーダイアログを表示する
			MessageDialog.openInformation(null, Messages.getString("message"),
					Messages.getString("message.accesscontrol.16"));
		} catch (FinderException e) {
		} catch (NamingException e) {
		} catch (CreateException e) {
		}
		
		return records;		
    }
    
    public ArrayList getMaintenanceTypeNameIdList() {
    	
    	MaintenanceController maintenance = EjbConnectionManager.getConnectionManager().getMaintenanceController();
    	ArrayList records = null;
    	
    	try {
			records = maintenance.getMaintenanceTypeNameIdList();
		} catch (RemoteException e) {
			// アクセス権なしの場合、エラーダイアログを表示する
			MessageDialog.openInformation(null, Messages.getString("message"),
					Messages.getString("message.accesscontrol.16"));
		} catch (FinderException e) {
		} catch (NamingException e) {
		} catch (CreateException e) {
		}
		return records;
    }
    
    public ArrayList getMaintenanceKeepNameIdList() {
    	
    	MaintenanceController maintenance = EjbConnectionManager.getConnectionManager().getMaintenanceController();
    	ArrayList records = null;
    	
		try {
			records = maintenance.getMaintenanceKeepNameIdList();
		} catch (RemoteException e) {
			// アクセス権なしの場合、エラーダイアログを表示する
			MessageDialog.openInformation(null, Messages.getString("message"),
					Messages.getString("message.accesscontrol.16"));
		} catch (FinderException e) {
		} catch (NamingException e) {
		} catch (CreateException e) {
		}
		
		return records;		
    }
}