/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.monitor.ui;

import org.eclipse.ui.IFolderLayout;
import org.eclipse.ui.IPageLayout;
import org.eclipse.ui.IPerspectiveFactory;

import com.clustercontrol.monitor.view.EventView;
import com.clustercontrol.monitor.view.ScopeView;
import com.clustercontrol.monitor.view.StatusView;

/**
 * 監視管理のパースペクティブを生成するクラスです。
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class MonitorPerspective implements IPerspectiveFactory {

    /**
     * 画面レイアウトを実装します。
     * 
     * @see org.eclipse.ui.IPerspectiveFactory#createInitialLayout(org.eclipse.ui.IPageLayout)
     */
    public void createInitialLayout(IPageLayout layout) {
        // アクションセットを追加
        layout.addActionSet("com.clustercontrol.ActionSet");
        layout.addActionSet("com.clustercontrol.collectiverun.ActionSet");
        layout.addActionSet("com.clustercontrol.jobmanagement.ActionSet");
        layout.addActionSet("com.clustercontrol.monitor.ActionSet");
        layout.addActionSet("com.clustercontrol.repository.ActionSet");
        layout.addActionSet("com.clustercontrol.syslogng.ActionSet");
        layout.addActionSet("com.clustercontrol.performance.ActionSet");
        layout.addActionSet("com.clustercontrol.accesscontrol.ActionSet");
        layout.addActionSet("com.clustercontrol.process.ActionSet");
        layout.addActionSet("com.clustercontrol.sql.ActionSet");
        layout.addActionSet("com.clustercontrol.ping.ActionSet");
        layout.addActionSet("com.clustercontrol.hinemosagent.ActionSet");
        layout.addActionSet("com.clustercontrol.snmp.ActionSet");
        layout.addActionSet("com.clustercontrol.priority.ActionSet");
        layout.addActionSet("com.clustercontrol.http.ActionSet");
        layout.addActionSet("com.clustercontrol.troubledetection.ActionSet");
        layout.addActionSet("com.clustercontrol.snmptrap.ActionSet");
        layout.addActionSet("com.clustercontrol.maintenance.ActionSet");
        
        //エディタ領域を非表示にする
        layout.setEditorAreaVisible(false);

        //エディタ領域のIDを取得
        String editorArea = layout.getEditorArea();

        //エディタ領域の上部66%を占めるフォルダを作成
        IFolderLayout top = layout.createFolder("top", IPageLayout.TOP,
                (float) 0.66f, editorArea);
        //ID=topのフォルダの下部50%を占めるフォルダの作成
        IFolderLayout middle = layout.createFolder("middle",
                IPageLayout.BOTTOM, (float) 0.5f, "top");
        //エディタ領域の下部34%を占めるフォルダを作成
        IFolderLayout bottom = layout.createFolder("bottom",
                IPageLayout.BOTTOM, (float) 0.34f, editorArea);

        top.addView(ScopeView.ID);
        middle.addView(StatusView.ID);
        bottom.addView(EventView.ID);
    }
}