/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.monitor.run.factory;

import java.util.Collection;

import javax.ejb.RemoveException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.monitor.run.ejb.entity.MonitorTruthValueInfoLocal;

/**
 * 真偽値監視の判定情報を削除する抽象クラスです。
 * <p>
 * 真偽値監視を行う各監視管理クラスで継承してください。
 *
 * @version 2.0.0
 * @since 2.0.0
 */
abstract public class DeleteMonitorTruthValueType extends DeleteMonitor{
	
	/** ログ出力のインスタンス。 */
	protected static Log m_log = LogFactory.getLog( DeleteMonitorTruthValueType.class );
	
	/**
	 * 監視情報より真偽値監視の判定情報を取得し、削除します。
	 * 
	 * @see #deleteTruthValueInfo(Collection)
	 * @see com.clustercontrol.monitor.run.ejb.entity.MonitorInfoBean
	 * @see com.clustercontrol.monitor.run.ejb.entity.MonitorTruthValueInfoBean
	 */
	@Override
	public boolean deleteJudgementInfo() throws RemoveException, NamingException {
		
		// 真偽値監視判定情報を削除
        Collection ct = m_monitor.getMonitorTruthValueInfo();
        this.deleteTruthValueInfo(ct);
        
		return true;
	}

	/**
	 * 引数で指定された真偽値監視判定情報を削除します。
	 * 
	 * @param ct 真偽値監視判定情報のコレクション
	 * @throws RemoveException
	 * 
	 * @see com.clustercontrol.monitor.run.ejb.entity.MonitorTruthValueInfoBean
	 */
	public void deleteTruthValueInfo(Collection ct) throws RemoveException {

		// 真偽値監視判定情報を削除
	    if(ct != null && ct.size() > 0){
	        Object[] infoArray = ct.toArray();
	        for(int j = 0; j < infoArray.length; j++){
	        	MonitorTruthValueInfoLocal info = (MonitorTruthValueInfoLocal)infoArray[j];
	            if(info != null){
	            	info.remove();
	            }
	        }
	    }
	}
}
