/*
                                                                                                
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
 
*/

package com.clustercontrol.sharedtable.bean;

import java.io.Serializable;
import java.util.Date;

/**
 * 時刻と値をセットで保持するクラス
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class ValueObject implements Serializable {
	private static final long serialVersionUID = 6308719037477348275L;

	private final String key;
	private final long date;
	private final Object value;
	
	public ValueObject(String key, long date, Object value){
		this.key = key;
		this.date = date;
		this.value = value;
	}
	
	/**
	 * 時刻を取得
	 * @return 時刻
	 */
	public long getDate() {
		return date;
	}
	
	/**
	 * 値を取得
	 * @return 値のオブジェクト
	 */
	public Object getValue() {
		return value;
	}
	
	/**
	 * キーを取得
	 * @return キー
	 */
	public String getKey() {
		return key;
	}

	/**
	 * 設定されている時刻と値の文字列表現を返します。
	 */
	public String toString(){
		return new Date(this.date) + " : "  + key+ " : " + this.value.toString();
	}
}
