/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.syslogng.util;

import javax.jms.JMSException;
import javax.jms.ObjectMessage;
import javax.jms.TopicPublisher;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.commons.util.CommonSendTopic;
import com.clustercontrol.syslogng.message.UpdateMonitorRuleInfo;

/**
 * トピックへメッセージを送信するクラスです。
 *
 * @version 2.1.0
 * @since 2.0.0
 */
public class SendTopic extends CommonSendTopic{
	
	/** ログ出力のインスタンス。 */
    protected static Log m_log = LogFactory.getLog( SendTopic.class );
    
    /**
     * コンストラクタ。<BR>
     * トピック名を設定します。初期処理を呼び出します。
     * 
     * @param topicName トピック名
     * @throws NamingException
     * @throws JMSException
     */
    public SendTopic(String topicName) throws NamingException, JMSException{
        super(topicName);
    }
       
    /**
     * 引数で指定されたメッセージをトピックへ送信します。
     * 
     * @param info フィルタ情報の更新情報
     * @throws JMSException
     */
    public void put(UpdateMonitorRuleInfo info) throws JMSException {
    	TopicPublisher publisher = null;
    	try{
    		publisher = m_session.createPublisher(m_topic);
    		
    		//送信メッセージ作成
    		ObjectMessage message = m_session.createObjectMessage(info);
    		message.setStringProperty("All", "true");
    		
    		//メッセージ送信
    		publisher.publish(message);
    		m_log.debug("put() topic ");
    	}
    	catch(JMSException e){
    		throw e;
    	}
    	finally{
    		try {
    			if (publisher != null)
    				publisher.close();
    		}
    		catch (JMSException e) {
    		}
    		
    		terminate();
    	}
    }
}